@@ -310,7 +310,7 @@ if (this.thisMesh != null) {
 var bsSets;
 if (Clazz.instanceOf (value, JU.BS)) {
 bsSets = (value);
-if (bsSets.cardinality () == 0) bsSets = null;
+if (bsSets.isEmpty ()) bsSets = null;
 } else {
 bsSets =  new JU.BS ();
 var a = value;
@@ -688,7 +688,7 @@ if (imesh.linkedMesh != null) cmd += " LINK";
 if (this.myType === "lcaoCartoon" && imesh.atomIndex >= 0) cmd += " ATOMINDEX " + imesh.atomIndex;
 J.shape.Shape.appendCmd (sb, cmd);
 var id = this.myType + " ID " + JU.PT.esc (imesh.thisID);
-if (imesh.jvxlData.thisSet != null && imesh.jvxlData.thisSet.cardinality () > 0) {
+if (imesh.jvxlData.thisSet != null && !imesh.jvxlData.thisSet.isEmpty ()) {
 J.shape.Shape.appendCmd (sb, id + (imesh.jvxlData.thisSet.cardinality () == 1 ? " set " + (imesh.jvxlData.thisSet.nextSetBit (0) + 1) : " subset " + imesh.jvxlData.thisSet));
 }if (imesh.mat4 != null && !imesh.isModelConnected) J.shape.Shape.appendCmd (sb, id + " move " + JU.Escape.matrixToScript (imesh.mat4));
 if (imesh.scale3d != 0) J.shape.Shape.appendCmd (sb, id + " scale3d " + imesh.scale3d);
