@@ -260,16 +260,27 @@ for (var i = this.bonds.length; --i >= 0; ) {
 n += this.bonds[i].getValence ();
 if (this.bonds[i].is (515)) npartial++;
 }
-if (n == 2 && npartial != 0) n++;
+if (n > 0 && n < 3 && npartial != 0) n++;
 }return n;
 });
 Clazz.overrideMethod (c$, "getCovalentBondCount", 
 function () {
 if (this.bonds == null) return 0;
 var n = 0;
-var b;
-for (var i = this.bonds.length; --i >= 0; ) if (((b = this.bonds[i]).order & 1023) != 0 && !b.getOtherAtom (this).isDeleted ()) ++n;
-
+for (var i = this.bonds.length; --i >= 0; ) {
+var b = this.bonds[i];
+if (b.isCovalentNotPartial0 () && !b.getOtherAtom (this).isDeleted ()) ++n;
+}
+return n;
+});
+Clazz.defineMethod (c$, "getCovalentOrPartialBondCount", 
+function () {
+if (this.bonds == null) return 0;
+var n = 0;
+for (var i = this.bonds.length; --i >= 0; ) {
+var b = this.bonds[i];
+if (b.isCovalent () && !b.getOtherAtom (this).isDeleted ()) ++n;
+}
 return n;
 });
 Clazz.overrideMethod (c$, "getCovalentHydrogenCount", 
@@ -277,10 +288,11 @@ function () {
 if (this.bonds == null) return 0;
 var n = 0;
 for (var i = this.bonds.length; --i >= 0; ) {
-if ((this.bonds[i].order & 1023) == 0) continue;
+var b = this.bonds[i];
+if (b.isCovalentNotPartial0 ()) {
 var a = this.bonds[i].getOtherAtom (this);
 if (a.valence >= 0 && a.getElementNumber () == 1) ++n;
-}
+}}
 return n;
 });
 Clazz.overrideMethod (c$, "getImplicitHydrogenCount", 
