@@ -1139,7 +1139,7 @@ if (bs.isEmpty ()) break;
 if (bsRestrict != null) {
 bs = JU.BSUtil.copy (bs);
 bs.and (bsRestrict);
-}var o = (bs.cardinality () == 0 ? null : this.eval.getBitsetProperty (bs, null, 1145047050, null, null, x.value, null, false, 2147483647, false));
+}var o = (bs.isEmpty () ? null : this.eval.getBitsetProperty (bs, null, 1145047050, null, null, x.value, null, false, 2147483647, false));
 return o;
 case 4:
 pt = JU.Escape.uP (JS.SV.sValue (x));
