@@ -1,5 +1,5 @@
 Clazz.declarePackage ("JS");
-Clazz.load (["J.api.SmilesMatcherInterface"], "JS.SmilesMatcher", ["JU.AU", "$.BS", "$.PT", "JS.InvalidSmilesException", "$.SmilesAtom", "$.SmilesBond", "$.SmilesGenerator", "$.SmilesParser", "$.SmilesSearch", "JU.BSUtil", "$.Elements", "$.Logger", "$.Node", "$.Point3fi"], function () {
+Clazz.load (["J.api.SmilesMatcherInterface"], "JS.SmilesMatcher", ["java.lang.Boolean", "JU.AU", "$.BS", "$.PT", "JS.InvalidSmilesException", "$.SmilesAtom", "$.SmilesBond", "$.SmilesGenerator", "$.SmilesParser", "$.SmilesSearch", "JU.BSUtil", "$.Elements", "$.Logger", "$.Node", "$.Point3fi"], function () {
 c$ = Clazz.decorateAsClass (function () {
 this.okMF = true;
 Clazz.instantialize (this, arguments);
@@ -55,6 +55,41 @@ for (var j = a.length; --j >= 0; ) a[j] = (search.targetAtoms[a[j]]).mapIndex;
 }
 return array;
 }, "~S,~S,~N");
+Clazz.overrideMethod (c$, "hasStructure", 
+function (pattern, smilesSet, flags) {
+var ret =  Clazz.newIntArray (smilesSet.length, 0);
+if ((flags & 1) != 1) {
+flags = flags | 2;
+}this.clearExceptions ();
+pattern = JS.SmilesParser.cleanPattern (pattern);
+try {
+var search = JS.SmilesParser.newSearch (pattern, true, false);
+for (var i = 0; i < smilesSet.length; i++) {
+var smiles = JS.SmilesParser.cleanPattern (smilesSet[i]);
+var searchTarget = JS.SmilesParser.newSearch (smiles, false, true);
+searchTarget.setFlags (searchTarget.flags | JS.SmilesParser.getFlags (pattern));
+try {
+ret[i] = (this.matchPattern (search, null, 0, null, null, false, flags | 8, 5, searchTarget) === Boolean.TRUE ? 1 : 0);
+} catch (e) {
+if (Clazz.exceptionOf (e, Exception)) {
+ret[i] = -1;
+e.printStackTrace ();
+} else {
+throw e;
+}
+}
+}
+} catch (e) {
+if (Clazz.exceptionOf (e, Exception)) {
+if (JU.Logger.debugging) e.printStackTrace ();
+if (JS.InvalidSmilesException.getLastError () == null) this.clearExceptions ();
+throw  new JS.InvalidSmilesException (JS.InvalidSmilesException.getLastError ());
+} else {
+throw e;
+}
+}
+return ret;
+}, "~S,~A,~N");
 Clazz.overrideMethod (c$, "getAtoms", 
 function (target) {
 this.clearExceptions ();
@@ -184,31 +219,53 @@ this.clearExceptions ();
 try {
 var isSmarts = ((flags & 2) == 2);
 var search = JS.SmilesParser.newSearch (pattern, isSmarts, false);
+if (searchTarget != null) searchTarget.setFlags (searchTarget.flags | JS.SmilesParser.getFlags (pattern));
+return this.matchPattern (search, atoms, ac, bsSelected, bsAromatic, doTestAromatic, flags, mode, searchTarget);
+} catch (e) {
+if (Clazz.exceptionOf (e, Exception)) {
+if (JU.Logger.debugging) e.printStackTrace ();
+if (JS.InvalidSmilesException.getLastError () == null) this.clearExceptions ();
+throw  new JS.InvalidSmilesException (JS.InvalidSmilesException.getLastError ());
+} else {
+throw e;
+}
+}
+}, "~S,~A,~N,JU.BS,JU.BS,~B,~N,~N,JS.SmilesSearch");
+Clazz.defineMethod (c$, "matchPattern", 
+ function (search, atoms, ac, bsSelected, bsAromatic, doTestAromatic, flags, mode, searchTarget) {
+var isSmarts = ((flags & 2) == 2);
 var isTopo = ((flags & 16384) == 16384);
 if (searchTarget != null) {
-search.haveTopo = true;
+search.haveSmilesTarget = true;
 bsAromatic =  new JU.BS ();
-searchTarget.setFlags (searchTarget.flags | JS.SmilesParser.getFlags (pattern));
 searchTarget.createTopoMap (bsAromatic);
 atoms = searchTarget.targetAtoms;
 ac = searchTarget.targetAtoms.length;
 if (isSmarts) {
 var a1 = searchTarget.elementCounts;
 var a2 = search.elementCounts;
-for (var i = Math.max (searchTarget.elementNumberMax, search.elementNumberMax); i > 0; i--) {
+var n = searchTarget.elementNumberMax;
+if (n == search.elementNumberMax) {
+for (var i = 1; i <= n; i++) {
 if (a1[i] < a2[i]) {
 this.okMF = false;
 break;
 }}
 } else {
-var mf = (isTopo ? null : search.getMolecularFormulaImpl (true, null, false));
-var s = searchTarget.getMolecularFormulaImpl (true, null, false);
-this.okMF = (mf == null || mf.equals (s));
-if (!this.okMF) {
-System.out.println ("\n" + pattern + "\n" + mf + " \n" + s);
-s = searchTarget.getMolecularFormulaImpl (true, null, false);
-}}searchTarget.mf = search.mf = null;
-}if (this.okMF) {
+this.okMF = false;
+}} else {
+var mf = search.getMFArray (true, null, false);
+var mft = searchTarget.getMFArray (true, null, false);
+var n = searchTarget.elementNumberMax;
+if (n == search.elementNumberMax) {
+for (var i = 2; i <= n; i++) {
+if (mf[i] != mft[i]) {
+this.okMF = false;
+break;
+}}
+} else {
+this.okMF = false;
+}}}if (this.okMF) {
 if (!isSmarts && !search.patternAromatic) {
 if (bsAromatic == null) bsAromatic =  new JU.BS ();
 search.normalizeAromaticity (bsAromatic);
@@ -220,7 +277,7 @@ if (ac != 0 && (bsSelected == null || !bsSelected.isEmpty ())) {
 var is3D = !(Clazz.instanceOf (atoms[0], JS.SmilesAtom));
 search.getSelections ();
 if (!doTestAromatic) search.bsAromatic = bsAromatic;
-search.setRingData (null, null, is3D || doTestAromatic);
+search.setRingData (null, null, is3D || doTestAromatic || search.patternAromatic);
 search.exitFirstMatch = ((flags & 8) == 8);
 search.mapUnique = ((flags & 128) == 128);
 }}switch (mode) {
@@ -244,24 +301,38 @@ search.getMaps = true;
 search.setFlags (flags | search.flags);
 var vl = search.search ();
 return vl.toArray (JU.AU.newInt2 (vl.size ()));
-}
-} catch (e) {
-if (Clazz.exceptionOf (e, Exception)) {
-if (JU.Logger.debugging) e.printStackTrace ();
-if (JS.InvalidSmilesException.getLastError () == null) this.clearExceptions ();
-throw  new JS.InvalidSmilesException (JS.InvalidSmilesException.getLastError ());
-} else {
-throw e;
-}
+case 5:
+if (!this.okMF) return Boolean.FALSE;
+search.retBoolean = true;
+search.setFlags (flags | search.flags);
+return search.search ();
 }
 return null;
-}, "~S,~A,~N,JU.BS,JU.BS,~B,~N,~N,JS.SmilesSearch");
+}, "JS.SmilesSearch,~A,~N,JU.BS,JU.BS,~B,~N,~N,JS.SmilesSearch");
 Clazz.overrideMethod (c$, "cleanSmiles", 
 function (smiles) {
 return JS.SmilesParser.cleanPattern (smiles);
 }, "~S");
 Clazz.overrideMethod (c$, "getMapForJME", 
 function (jme, at, bsAtoms) {
+try {
+var molecule = JS.SmilesMatcher.jmeToMolecule (jme);
+var bs = JU.BSUtil.newBitSet2 (0, molecule.ac);
+var s = this.getSmiles (molecule.patternAtoms, molecule.ac, bs, null, 34);
+var map = this.getCorrelationMaps (s, molecule.patternAtoms, molecule.ac, bs, 42);
+var map2 = this.getCorrelationMaps (s, at, bsAtoms.cardinality (), bsAtoms, 42);
+return  Clazz.newArray (-1, [map[0], map2[0]]);
+} catch (e) {
+if (Clazz.exceptionOf (e, Exception)) {
+e.printStackTrace ();
+} else {
+throw e;
+}
+}
+return null;
+}, "~S,~A,JU.BS");
+c$.jmeToMolecule = Clazz.defineMethod (c$, "jmeToMolecule", 
+function (jme) {
 var molecule =  new JS.SmilesSearch ();
 var tokens = JU.PT.getTokens (jme);
 var nAtoms = JU.PT.parseInt (tokens[0]);
@@ -299,27 +370,28 @@ break;
 }
  new JS.SmilesBond (a1, a2, order, false).index = i;
 }
-var s = "";
-try {
 molecule.isSmarts = true;
 molecule.set ();
-var bs = JU.BSUtil.newBitSet2 (0, nAtoms);
-s = this.getSmiles (molecule.patternAtoms, molecule.ac, bs, null, 34);
-var map = this.getCorrelationMaps (s, molecule.patternAtoms, nAtoms, bs, 42);
-var map2 = this.getCorrelationMaps (s, at, bsAtoms.cardinality (), bsAtoms, 42);
-return  Clazz.newArray (-1, [map[0], map2[0]]);
+return molecule;
+}, "~S");
+Clazz.overrideMethod (c$, "getSmilesFromJME", 
+function (jme) {
+try {
+var molecule = JS.SmilesMatcher.jmeToMolecule (jme);
+var bs = JU.BSUtil.newBitSet2 (0, molecule.ac);
+return this.getSmiles (molecule.patternAtoms, molecule.ac, bs, null, 1);
 } catch (e) {
 if (Clazz.exceptionOf (e, Exception)) {
-e.printStackTrace ();
+return null;
 } else {
 throw e;
 }
 }
-return null;
-}, "~S,~A,JU.BS");
+}, "~S");
 Clazz.defineStatics (c$,
 "MODE_BITSET", 0x01,
 "MODE_ARRAY", 0x02,
 "MODE_MAP", 0x03,
-"MODE_ATROP", 0x04);
+"MODE_ATROP", 0x04,
+"MODE_BOOLEAN", 0x05);
 });
