@@ -1,5 +1,5 @@
 Clazz.declarePackage ("JS");
-Clazz.load (["JU.JmolMolecule", "JU.BS", "$.Lst"], "JS.SmilesSearch", ["java.lang.Float", "java.util.Hashtable", "JU.AU", "$.SB", "JS.InvalidSmilesException", "$.SmilesAromatic", "$.SmilesAtom", "$.SmilesBond", "$.SmilesMeasure", "$.SmilesParser", "$.SmilesStereo", "$.VTemp", "JU.BSUtil", "$.Logger"], function () {
+Clazz.load (["JU.JmolMolecule", "JU.BS", "$.Lst"], "JS.SmilesSearch", ["java.lang.Boolean", "$.Float", "java.util.Hashtable", "JU.AU", "$.SB", "JS.InvalidSmilesException", "$.SmilesAromatic", "$.SmilesAtom", "$.SmilesBond", "$.SmilesMeasure", "$.SmilesParser", "$.SmilesStereo", "$.VTemp", "JU.BSUtil", "$.Logger"], function () {
 c$ = Clazz.decorateAsClass (function () {
 this.isSmarts = false;
 this.top = null;
@@ -25,7 +25,7 @@ this.exitFirstMatch = false;
 this.groupByModel = false;
 this.setAtropicity = false;
 this.patternAromatic = false;
-this.haveTopo = false;
+this.haveSmilesTarget = false;
 this.isTopology = false;
 this.patternBioSequence = false;
 this.subSearches = null;
@@ -48,6 +48,7 @@ this.atropKeys = null;
 this.lastChainAtom = null;
 this.asVector = false;
 this.getMaps = false;
+this.retBoolean = false;
 this.isNormalized = false;
 this.haveComponents = false;
 this.isSilent = false;
@@ -319,7 +320,7 @@ search.targetAtomCount = this.targetAtomCount;
 search.bsSelected = this.bsSelected;
 search.selectedAtomCount = this.selectedAtomCount;
 search.htNested = this.htNested;
-search.haveTopo = this.haveTopo;
+search.haveSmilesTarget = this.haveSmilesTarget;
 search.bsCheck = this.bsCheck;
 search.isSmarts = true;
 search.bsAromatic = this.bsAromatic;
@@ -343,6 +344,7 @@ search.aromaticDouble = this.aromaticDouble;
 search.haveSelected = this.haveSelected;
 search.exitFirstMatch = this.exitFirstMatch;
 search.getMaps = this.getMaps;
+search.retBoolean = this.retBoolean;
 search.asVector = this.asVector;
 search.vReturn = this.vReturn;
 search.bsReturn = this.bsReturn;
@@ -353,6 +355,7 @@ return search.search2 (submode == 1);
 }, "JS.SmilesSearch,~N");
 Clazz.defineMethod (c$, "search", 
 function () {
+this.bsReturn.clearAll ();
 return this.search2 (false);
 });
 Clazz.defineMethod (c$, "search2", 
@@ -373,7 +376,7 @@ this.clearBsFound (-1);
 } else {
 this.bsReturn.clearAll ();
 }this.nextPatternAtom (-1, -1, firstAtomOnly, -1);
-}return (this.asVector || this.getMaps ? this.vReturn : this.bsReturn);
+}return (this.asVector || this.getMaps ? this.vReturn : !this.retBoolean ? this.bsReturn : Boolean.$valueOf (!this.bsReturn.isEmpty ()));
 }, "~B");
 Clazz.defineMethod (c$, "nextPatternAtom", 
  function (atomNum, iAtom, firstAtomOnly, c) {
@@ -706,7 +709,7 @@ case 1:
 bondFound = !this.isSmarts || !JS.SmilesSearch.isRingBond (this.ringSets, this.getBSAromaticRings (), iAtom1, iAtom2);
 break;
 case 2:
-bondFound = this.isNormalized || this.aromaticDouble && (order == 2 || order == 514);
+bondFound = this.isNormalized || order == 81 || this.aromaticDouble && (order == 2 || order == 514);
 break;
 case 65537:
 case 65538:
@@ -863,7 +866,7 @@ var dbAtom2 = sAtom2.getMatchingAtom ();
 var dbAtom1a = sAtomDirected1.getMatchingAtom ();
 var dbAtom2a = sAtomDirected2.getMatchingAtom ();
 if (dbAtom1a == null || dbAtom2a == null) return false;
-if (this.haveTopo) JS.SmilesSearch.setTopoCoordinates (dbAtom1, dbAtom2, dbAtom1a, dbAtom2a, bondType);
+if (this.haveSmilesTarget) JS.SmilesSearch.setTopoCoordinates (dbAtom1, dbAtom2, dbAtom1a, dbAtom2a, bondType);
 var d = JS.SmilesMeasure.setTorsionData (dbAtom1a, dbAtom1, dbAtom2, dbAtom2a, this.v, isAtropisomer);
 if (isAtropisomer) {
 d *= dir1 * (bondType == 65537 ? 1 : -1) * (indexOrder ? 1 : -1) * 1 * -1;
@@ -979,6 +982,8 @@ atom.residueChar = sAtom.residueChar;
 atom.residueNumber = sAtom.residueNumber;
 atom.atomNumber = sAtom.residueNumber;
 atom.insCode = sAtom.insCode;
+atom.hasDoubleBond = sAtom.hasDoubleBond;
+atom.isAromatic = sAtom.isAromatic;
 atom.atomClass = sAtom.atomClass;
 atom.explicitHydrogenCount = 0;
 atom.isBioAtom = sAtom.isBioAtom;
@@ -1067,7 +1072,7 @@ ss.setRingData (null, vRings, true);
 bsAromatic.or (ss.bsAromatic);
 if (!bsAromatic.isEmpty ()) {
 var lst = vRings[3];
-for (var i = lst.size (); --i >= 0; ) {
+if (lst != null) for (var i = lst.size (); --i >= 0; ) {
 var bs = lst.get (i);
 for (var j = bs.nextSetBit (0); j >= 0; j = bs.nextSetBit (j + 1)) {
 var a = atoms[j];
