@@ -18,10 +18,10 @@ Clazz.makeConstructor (c$,
 function () {
 });
 Clazz.overrideMethod (c$, "setPointGroup", 
-function (siLast, center, atomset, bsAtoms, haveVibration, distanceTolerance, linearTolerance, localEnvOnly) {
-this.pointGroup = JS.PointGroup.getPointGroup (siLast == null ? null : (siLast).pointGroup, center, atomset, bsAtoms, haveVibration, distanceTolerance, linearTolerance, localEnvOnly);
+function (siLast, center, atomset, bsAtoms, haveVibration, distanceTolerance, linearTolerance, maxAtoms, localEnvOnly) {
+this.pointGroup = JS.PointGroup.getPointGroup (siLast == null ? null : (siLast).pointGroup, center, atomset, bsAtoms, haveVibration, distanceTolerance, linearTolerance, maxAtoms, localEnvOnly);
 return this;
-}, "J.api.SymmetryInterface,JU.T3,~A,JU.BS,~B,~N,~N,~B");
+}, "J.api.SymmetryInterface,JU.T3,~A,JU.BS,~B,~N,~N,~N,~B");
 Clazz.overrideMethod (c$, "getPointGroupName", 
 function () {
 return this.pointGroup.getName ();
@@ -61,9 +61,9 @@ if (this.spaceGroup != null && JU.Logger.debugging) JU.Logger.debug ("using gene
 return this.spaceGroup != null;
 }, "~N,~S,~O,~N");
 Clazz.overrideMethod (c$, "getSpaceGroupInfoObj", 
-function (name, cellInfo, isFull, addNonstandard) {
-return JS.SpaceGroup.getInfo (this.spaceGroup, name, cellInfo, isFull, addNonstandard);
-}, "~S,J.api.SymmetryInterface,~B,~B");
+function (name, params, isFull, addNonstandard) {
+return JS.SpaceGroup.getInfo (this.spaceGroup, name, params, isFull, addNonstandard);
+}, "~S,~A,~B,~B");
 Clazz.overrideMethod (c$, "getLatticeDesignation", 
 function () {
 return this.spaceGroup.getLatticeDesignation ();
@@ -83,10 +83,6 @@ Clazz.overrideMethod (c$, "getSpaceGroupOperation",
 function (i) {
 return (this.spaceGroup == null || this.spaceGroup.operations == null || i >= this.spaceGroup.operations.length ? null : this.spaceGroup.finalOperations == null ? this.spaceGroup.operations[i] : this.spaceGroup.finalOperations[i]);
 }, "~N");
-Clazz.overrideMethod (c$, "getSpaceGroupOperationRaw", 
-function (i) {
-return this.spaceGroup.getRawOperation (i);
-}, "~N");
 Clazz.overrideMethod (c$, "getSpaceGroupXyz", 
 function (i, doNormalize) {
 return this.spaceGroup.getXyz (i, doNormalize);
@@ -553,9 +549,9 @@ function (uc) {
 this.unitCell = JS.UnitCell.cloneUnitCell ((uc).unitCell);
 }, "J.api.SymmetryInterface");
 Clazz.overrideMethod (c$, "findSpaceGroup", 
-function (vwr, atoms, opXYZ, asString) {
-return (J.api.Interface.getInterface ("JS.SpaceGroupFinder", vwr, "eval")).findSpaceGroup (vwr, atoms, opXYZ, this, asString);
-}, "JV.Viewer,JU.BS,~S,~B");
+function (vwr, atoms, xyzList, unitCell, asString, isAssign) {
+return (J.api.Interface.getInterface ("JS.SpaceGroupFinder", vwr, "eval")).findSpaceGroup (vwr, atoms, xyzList, unitCell, this, asString, isAssign);
+}, "JV.Viewer,JU.BS,~S,~A,~B,~B");
 Clazz.overrideMethod (c$, "setSpaceGroupTo", 
 function (sg) {
 this.symmetryInfo = null;
@@ -665,6 +661,14 @@ function (m, atom1, x, y, z, atom2) {
 m.rotTrans2 (atom1, atom2);
 atom2.add3 (x, y, z);
 }, "JU.M4,JU.P3,~N,~N,~N,JU.P3");
+Clazz.overrideMethod (c$, "isWithinUnitCell", 
+function (pt, a, b, c) {
+return this.unitCell.isWithinUnitCell (a, b, c, pt);
+}, "JU.P3,~N,~N,~N");
+Clazz.overrideMethod (c$, "checkPeriodic", 
+function (pt) {
+return this.unitCell.checkPeriodic (pt);
+}, "JU.P3");
 Clazz.defineStatics (c$,
 "nullDesc", null);
 });
