@@ -22,12 +22,12 @@ this.vwr.getBooleanProperty("minimizationRefresh");this.vwr.setStringProperty("_
 this.setMinimizationOn(!1);if(null==this.pFF)System.out.println("pFF was null");else{var a=this.pFF.detectExplosion();a&&this.restoreCoordinates();this.vwr.setIntProperty("_minimizationStep",this.pFF.getCurrentStep());this.reportEnergy();this.vwr.setStringProperty("_minimizationStatus",a?"failed":"done");this.vwr.notifyMinimizationStatus();this.vwr.refresh(3,"minimize:done"+(a?" EXPLODED":"OK"))}JU.Logger.info("minimize: endMinimization")});d(c$,"saveCoordinates",function(){null==this.coordSaved&&
 (this.coordSaved=s(this.ac,3,0));for(var a=0;a<this.ac;a++)for(var b=0;3>b;b++)this.coordSaved[a][b]=this.minAtoms[a].coord[b]});d(c$,"restoreCoordinates",function(){if(null!=this.coordSaved){for(var a=0;a<this.ac;a++)for(var b=0;3>b;b++)this.minAtoms[a].coord[b]=this.coordSaved[a][b];this.updateAtomXYZ()}});d(c$,"stopMinimization",function(a){this.$minimizationOn&&(this.setMinimizationOn(!1),a?this.endMinimization():this.restoreCoordinates())},"~B");d(c$,"updateAtomXYZ",function(){if(!(0>=this.steps)){if(null==
 this.bsBasis)for(var a=0;a<this.ac;a++){var b=this.minAtoms[a];b.atom.set(b.coord[0],b.coord[1],b.coord[2])}else{for(var c,a=0;a<this.ac;a++)if(!(null!=this.bsFixed&&this.bsFixed.get(a))&&(b=this.minAtoms[a],this.bsBasis.get((c=b.atom).i)))this.p.set(b.coord[0],b.coord[1],b.coord[2]),this.vwr.getModelkit(!1).moveConstrained(c.i,this.p,!0,!0);for(a=0;a<this.ac;a++)b=this.minAtoms[a],b.coord[0]=(c=b.atom).x,b.coord[1]=c.y,b.coord[2]=c.z}this.vwr.refreshMeasures(!1)}});d(c$,"minimizeWithoutThread",function(){if(this.startMinimization()){for(;this.stepMinimization(););
-this.endMinimization()}});d(c$,"report",function(a,b){this.isSilent?JU.Logger.info(a):b?this.vwr.showString(a,!1):this.vwr.scriptEcho(a)},"~S,~B");d(c$,"calculatePartialCharges",function(a,b,c){var e=new JM.FF.ForceFieldMMFF(this,!1);e.setArrays(a.at,b,a.bo,a.bondCount,!0,!0);this.vwr.setAtomProperty(b,1086326785,0,0,null,null,e.getAtomTypeDescriptions());this.vwr.setAtomProperty(null==c?b:c,1111492619,0,0,null,e.getPartialCharges(),null)},"JM.ModelSet,JU.BS,JU.BS")});r("JM");c$=v(function(){this.data=
-null;this.type=0;this.ddata=this.key=null;t(this,arguments)},JM,"MinObject");m(c$,"toString",function(){return this.type+" "+this.data[0]+","+this.data[1]+(2<this.data.length?","+this.data[2]+","+this.data[3]:"")+" "+JM.MinObject.decodeKey(this.key)});c$.getKey=d(c$,"getKey",function(a,b,c,e,f){return Integer.$valueOf(((((f<<7)+e<<7)+c<<7)+b<<4)+a)},"~N,~N,~N,~N,~N");c$.decodeKey=d(c$,"decodeKey",function(a){if(null==a)return null;var b=a.intValue();a=b&15;var b=b>>4,c=b&127,b=b>>7,e=b&127,b=b>>7,
-f=b&127,b=b>>7&127;return(0>a?a+": ":"")+(10>c?"  ":" ")+c+(10>e?"  ":" ")+e+(10>f?"  ":" ")+f+(120<b?"":(10>b?"  ":" ")+b)},"Integer");r("JM");p(["JM.MinObject"],"JM.MinAngle",null,function(){c$=v(function(){this.sbType=0;this.sbKey=null;this.ka=0;this.theta0=NaN;t(this,arguments)},JM,"MinAngle",JM.MinObject);y(c$,function(a){C(this,JM.MinAngle,[]);this.data=a},"~A")});r("JM");p(["JU.BS","$.Lst"],"JM.MinAtom",null,function(){c$=v(function(){this.index=0;this.ffAtomType=this.atom=this.sType=null;
-this.ffType=0;this.bonds=this.force=this.coord=this.vdwKey=null;this.partialCharge=this.hCount=this.nBonds=0;this.bondedAtoms=this.bs14=this.bsVdw=null;t(this,arguments)},JM,"MinAtom");B(c$,function(){this.coord=s(3,0);this.force=s(3,0);this.bonds=new JU.Lst;this.bsVdw=new JU.BS;this.bs14=new JU.BS});m(c$,"toString",function(){return"#"+this.index+" "+this.sType});y(c$,function(a,b,c,e){this.index=a;this.atom=b;this.coord=c;this.bsVdw.setBits(a+1,e);this.bsVdw.clear(a);this.hCount=b.getCovalentHydrogenCount()},
-"~N,JM.Atom,~A,~N");d(c$,"set",function(){this.coord[0]=this.atom.x;this.coord[1]=this.atom.y;this.coord[2]=this.atom.z});d(c$,"getBondTo",function(a){this.getBondedAtomIndexes();for(var b=0;b<this.nBonds;b++)if(this.bondedAtoms[b]==a)return this.bonds.get(b);return null},"~N");d(c$,"getBondedAtomIndexes",function(){if(null==this.bondedAtoms){this.bondedAtoms=q(this.nBonds,0);for(var a=this.nBonds;0<=--a;)this.bondedAtoms[a]=this.bonds.get(a).getOtherAtom(this.index)}return this.bondedAtoms});d(c$,
-"getIdentity",function(){return this.atom.getInfo()});d(c$,"addBond",function(a,b){this.bonds.addLast(a);this.nBonds++;this.bsVdw.clear(b)},"JM.MinBond,~N");d(c$,"getBondIndex",function(a){return this.bonds.get(a).index},"~N");c$.isLinear=d(c$,"isLinear",function(a){switch(a.ffType){case 4:case 53:case 61:return!0}return!1},"JM.MinAtom")});r("JM");p(["JM.MinObject"],"JM.MinBond",null,function(){c$=v(function(){this.order=this.index=this.rawIndex=0;this.isAmide=this.isAromatic=!1;t(this,arguments)},
+this.endMinimization()}});d(c$,"report",function(a,b){this.isSilent?JU.Logger.info(a):b?this.vwr.showString(a,!1):this.vwr.scriptEcho(a)},"~S,~B");d(c$,"calculatePartialCharges",function(a,b,c){var e=new JM.FF.ForceFieldMMFF(this,!1);e.setArrays(a.at,b,a.bo,a.bondCount,!0,!0);this.vwr.setAtomProperty(b,1086326785,0,0,null,null,e.getAtomTypeDescriptions());this.vwr.setAtomProperty(null==c?b:c,1111492619,0,0,null,e.getPartialCharges(),null)},"JM.ModelSet,JU.BS,JU.BS");d(c$,"getForceFieldUsed",function(){return null==
+this.pFF?null:this.pFF.name})});r("JM");c$=v(function(){this.data=null;this.type=0;this.ddata=this.key=null;t(this,arguments)},JM,"MinObject");m(c$,"toString",function(){return this.type+" "+this.data[0]+","+this.data[1]+(2<this.data.length?","+this.data[2]+","+this.data[3]:"")+" "+JM.MinObject.decodeKey(this.key)});c$.getKey=d(c$,"getKey",function(a,b,c,e,f){return Integer.$valueOf(((((f<<7)+e<<7)+c<<7)+b<<4)+a)},"~N,~N,~N,~N,~N");c$.decodeKey=d(c$,"decodeKey",function(a){if(null==a)return null;
+var b=a.intValue();a=b&15;var b=b>>4,c=b&127,b=b>>7,e=b&127,b=b>>7,f=b&127,b=b>>7&127;return(0>a?a+": ":"")+(10>c?"  ":" ")+c+(10>e?"  ":" ")+e+(10>f?"  ":" ")+f+(120<b?"":(10>b?"  ":" ")+b)},"Integer");r("JM");p(["JM.MinObject"],"JM.MinAngle",null,function(){c$=v(function(){this.sbType=0;this.sbKey=null;this.ka=0;this.theta0=NaN;t(this,arguments)},JM,"MinAngle",JM.MinObject);y(c$,function(a){C(this,JM.MinAngle,[]);this.data=a},"~A")});r("JM");p(["JU.BS","$.Lst"],"JM.MinAtom",null,function(){c$=v(function(){this.index=
+0;this.ffAtomType=this.atom=this.sType=null;this.ffType=0;this.bonds=this.force=this.coord=this.vdwKey=null;this.partialCharge=this.hCount=this.nBonds=0;this.bondedAtoms=this.bs14=this.bsVdw=null;t(this,arguments)},JM,"MinAtom");B(c$,function(){this.coord=s(3,0);this.force=s(3,0);this.bonds=new JU.Lst;this.bsVdw=new JU.BS;this.bs14=new JU.BS});m(c$,"toString",function(){return"#"+this.index+" "+this.sType});y(c$,function(a,b,c,e){this.index=a;this.atom=b;this.coord=c;this.bsVdw.setBits(a+1,e);this.bsVdw.clear(a);
+this.hCount=b.getCovalentHydrogenCount()},"~N,JM.Atom,~A,~N");d(c$,"set",function(){this.coord[0]=this.atom.x;this.coord[1]=this.atom.y;this.coord[2]=this.atom.z});d(c$,"getBondTo",function(a){this.getBondedAtomIndexes();for(var b=0;b<this.nBonds;b++)if(this.bondedAtoms[b]==a)return this.bonds.get(b);return null},"~N");d(c$,"getBondedAtomIndexes",function(){if(null==this.bondedAtoms){this.bondedAtoms=q(this.nBonds,0);for(var a=this.nBonds;0<=--a;)this.bondedAtoms[a]=this.bonds.get(a).getOtherAtom(this.index)}return this.bondedAtoms});
+d(c$,"getIdentity",function(){return this.atom.getInfo()});d(c$,"addBond",function(a,b){this.bonds.addLast(a);this.nBonds++;this.bsVdw.clear(b)},"JM.MinBond,~N");d(c$,"getBondIndex",function(a){return this.bonds.get(a).index},"~N");c$.isLinear=d(c$,"isLinear",function(a){switch(a.ffType){case 4:case 53:case 61:return!0}return!1},"JM.MinAtom")});r("JM");p(["JM.MinObject"],"JM.MinBond",null,function(){c$=v(function(){this.order=this.index=this.rawIndex=0;this.isAmide=this.isAromatic=!1;t(this,arguments)},
 JM,"MinBond",JM.MinObject);y(c$,function(a,b,c,e,f,g,h){C(this,JM.MinBond,[]);this.rawIndex=a;this.index=b;this.type=g;this.data=q(-1,[c,e]);this.order=f;this.key=h},"~N,~N,~N,~N,~N,~N,Integer");d(c$,"getOtherAtom",function(a){return this.data[this.data[0]==a?1:0]},"~N")});r("JM");p(["JM.MinObject"],"JM.MinTorsion",null,function(){c$=x(JM,"MinTorsion",JM.MinObject);y(c$,function(a){C(this,JM.MinTorsion,[]);this.data=a},"~A")});r("JM");p(null,"JM.Util",["java.lang.Double","java.util.Random"],function(){c$=
 x(JM,"Util");c$.sub=d(c$,"sub",function(a,b,c){c.set(a[0]-b[0],a[1]-b[1],a[2]-b[2])},"~A,~A,JU.V3d");c$.putCoord=d(c$,"putCoord",function(a,b){b[0]=a.x;b[1]=a.y;b[2]=a.z},"JU.V3d,~A");c$.distance2=d(c$,"distance2",function(a,b){var c=a[0]-b[0],e=a[1]-b[1],f=a[2]-b[2];return c*c+e*e+f*f},"~A,~A");c$.distance2V=d(c$,"distance2V",function(a,b){var c=a.x-b.x,e=a.y-b.y,f=a.z-b.z;return c*c+e*e+f*f},"JU.V3d,JU.V3d");c$.getAngleRadiansABC=d(c$,"getAngleRadiansABC",function(a,b,c){var e=JM.Util.distance2(a,
 b);b=JM.Util.distance2(b,c);a=JM.Util.distance2(a,c);return JM.Util.isNearZero2(e,0.001)||JM.Util.isNearZero2(b,0.001)?0:Math.acos((e+b-a)/2/Math.sqrt(e*b))},"~A,~A,~A");c$.isApprox=d(c$,"isApprox",function(a,b,c){return JM.Util.distance2V(a,b)<=c*c*Math.min(a.lengthSquared(),b.lengthSquared())},"JU.V3d,JU.V3d,~N");c$.canBeSquared=d(c$,"canBeSquared",function(a){return 0==a?!0:1E150>(a=Math.abs(a))&&1E-150<a},"~N");c$.isNegligible=d(c$,"isNegligible",function(a,b){return JM.Util.isNegligible3(a,b,
@@ -58,7 +58,7 @@ w(c$,"ENERGY",1,"EBOND",2,"EANGLE",4,"ESTRBND",8,"ETORSION",16,"EOOP",32,"EVDW",
 this.vRings=this.rawMMFF94Charges=this.rawBondTypes=this.rawAtomTypes=this.ffParams=null;t(this,arguments)},JM.FF,"ForceFieldMMFF",JM.FF.ForceField);B(c$,function(){this.typeData=q(4,0)});d(c$,"getAtomTypeDescriptions",function(){return JM.FF.ForceFieldMMFF.getAtomTypeDescs(this.rawAtomTypes)});d(c$,"getPartialCharges",function(){return this.rawMMFF94Charges});y(c$,function(a,b){C(this,JM.FF.ForceFieldMMFF,[]);this.minimizer=a;b?(this.name="MMFF2D",this.ffParams=JM.FF.ForceFieldMMFF.mmff2DParams,
 null==this.ffParams&&(JM.FF.ForceFieldMMFF.mmff2DParams=this.ffParams=this.getParameters(!0))):(this.name="MMFF",this.ffParams=JM.FF.ForceFieldMMFF.mmffParams,null==this.ffParams&&(JM.FF.ForceFieldMMFF.mmffParams=this.ffParams=this.getParameters(!1)))},"JM.Minimizer,~B");m(c$,"clear",function(){});m(c$,"setModel",function(){var a=this.minimizer;if(!this.setArrays(a.atoms,a.bsAtoms,a.bonds,a.rawBondCount,!1,!1))return!1;this.setModelFields();if(!this.fixTypes())return!1;this.calc=new JM.FF.CalculationsMMFF(this,
 this.ffParams,this.minAtoms,this.minBonds,this.minAngles,this.minTorsions,this.minPositions,this.minimizer.constraints);this.calc.setLoggingEnabled(!0);return this.calc.setupCalculations()},"JU.BS,~N");d(c$,"setArrays",function(a,b,c,e,f,g){var d=this.minimizer;this.vRings=JU.AU.createArrayOfArrayList(4);this.rawAtomTypes=JM.FF.ForceFieldMMFF.setAtomTypes(a,b,d.vwr.getSmilesMatcher(),this.vRings,g);if(null==this.rawAtomTypes)return!1;this.rawBondTypes=this.setBondTypes(c,e,b);this.rawMMFF94Charges=
-this.calculatePartialCharges(c,this.rawBondTypes,a,this.rawAtomTypes,b,f);return!0},"~A,JU.BS,~A,~N,~B,~B");d(c$,"getParameters",function(a){this.getAtomTypes();a=a?"mmff94.par.txt":"mmff94_2d.par.txt";var b=new java.util.Hashtable;JU.Logger.debugging&&JU.Logger.debug("reading data from "+a);var c=null,e=null;try{for(var c=this.getBufferedReader(a),f=0,g=0;;){for(;0>(f=(e=c.readLine()).indexOf(".PAR")););if(1>(g=JM.FF.ForceFieldMMFF.types[F("END.BCI.CHG.ANG.NDK.OND.OOP.TBN.FSB.TOR.VDW.".indexOf(e.substring(f-
+this.calculatePartialCharges(c,this.rawBondTypes,a,this.rawAtomTypes,b,f);return!0},"~A,JU.BS,~A,~N,~B,~B");d(c$,"getParameters",function(a){this.getAtomTypes();a=a?"mmff94_2d.par.txt":"mmff94.par.txt";var b=new java.util.Hashtable;JU.Logger.debugging&&JU.Logger.debug("reading data from "+a);var c=null,e=null;try{for(var c=this.getBufferedReader(a),f=0,g=0;;){for(;0>(f=(e=c.readLine()).indexOf(".PAR")););if(1>(g=JM.FF.ForceFieldMMFF.types[F("END.BCI.CHG.ANG.NDK.OND.OOP.TBN.FSB.TOR.VDW.".indexOf(e.substring(f-
 3,f+1))/4)]))break;this.readParams(c,g,b)}c.close()}catch(d){if(A(d,JV.JmolAsyncException))throw new JV.JmolAsyncException(d.getFileName());if(A(d,Exception))System.err.println("Exception "+d.toString()+" in getResource "+a+" line="+e);else throw d;}finally{try{c.close()}catch(k){if(!A(k,Exception))throw k;}}return b},"~B");d(c$,"readParams",function(a,b,c){var e=null,f=0,g=127,d=127,k=127,n=0;switch(b){case 34:k=124;break;case 21:k=125;break;case 546:k=123;n=0;break;case 13:n=6;break;case 1:n=0;
 break;case 37:k=126;n=0;break;case 17:k=122,n=0}for(;!a.readLine().startsWith("*"););for(;(this.line=a.readLine()).startsWith("*"););do{switch(b){case 17:if(" "!=this.line.charAt(5))continue;break;case 34:if("4"==this.line.charAt(0))continue;case 5:case 3:case 21:case 9:n=this.line.charCodeAt(0)-48}switch(b){case 13:case 9:k=this.ival(18,20);case 5:case 21:case 37:d=this.ival(13,15);case 546:case 3:case 34:g=this.ival(8,10);case 1:case 17:f=this.ival(3,5)}switch(b){case 546:e=s(-1,[this.dval(19,25),
 this.dval(13,18)]);break;case 3:e=s(-1,[this.dval(14,20),this.dval(25,31)]);break;case 5:case 21:e=s(-1,[this.dval(19,25),this.dval(28,35)]);break;case 34:e=Float.$valueOf(this.fval(10,20));break;case 13:e=s(-1,[this.dval(24,30)]);break;case 1:e=Float.$valueOf(this.fval(5,15));break;case 37:var u=this.dval(19,25),l=this.dval(28,35),e=s(-1,[u,l]),j=JM.MinObject.getKey(n,f,g,d,k);c.put(j,e);e=s(-1,[l,u]);u=f;f=d;d=u;break;case 9:e=s(-1,[this.dval(22,28),this.dval(30,36),this.dval(38,44)]);break;case 17:e=
